@@ -1,7 +1,7 @@
 """
 Type annotations for backup-gateway service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/type_defs/)
 
 Usage::
 
@@ -88,15 +88,28 @@ AssociateGatewayToServerOutputTypeDef = TypedDict(
     },
 )
 
-CreateGatewayInputRequestTypeDef = TypedDict(
-    "CreateGatewayInputRequestTypeDef",
+_RequiredCreateGatewayInputRequestTypeDef = TypedDict(
+    "_RequiredCreateGatewayInputRequestTypeDef",
     {
         "ActivationKey": str,
         "GatewayDisplayName": str,
         "GatewayType": Literal["BACKUP_VM"],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateGatewayInputRequestTypeDef = TypedDict(
+    "_OptionalCreateGatewayInputRequestTypeDef",
+    {
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateGatewayInputRequestTypeDef(
+    _RequiredCreateGatewayInputRequestTypeDef, _OptionalCreateGatewayInputRequestTypeDef
+):
+    pass
+
 
 CreateGatewayOutputTypeDef = TypedDict(
     "CreateGatewayOutputTypeDef",
@@ -154,36 +167,52 @@ DisassociateGatewayFromServerOutputTypeDef = TypedDict(
 GatewayTypeDef = TypedDict(
     "GatewayTypeDef",
     {
-        "GatewayArn": NotRequired[str],
-        "GatewayDisplayName": NotRequired[str],
-        "GatewayType": NotRequired[Literal["BACKUP_VM"]],
-        "HypervisorId": NotRequired[str],
-        "LastSeenTime": NotRequired[datetime],
+        "GatewayArn": str,
+        "GatewayDisplayName": str,
+        "GatewayType": Literal["BACKUP_VM"],
+        "HypervisorId": str,
+        "LastSeenTime": datetime,
     },
+    total=False,
 )
 
 HypervisorTypeDef = TypedDict(
     "HypervisorTypeDef",
     {
-        "Host": NotRequired[str],
-        "HypervisorArn": NotRequired[str],
-        "KmsKeyArn": NotRequired[str],
-        "Name": NotRequired[str],
-        "State": NotRequired[HypervisorStateType],
+        "Host": str,
+        "HypervisorArn": str,
+        "KmsKeyArn": str,
+        "Name": str,
+        "State": HypervisorStateType,
     },
+    total=False,
 )
 
-ImportHypervisorConfigurationInputRequestTypeDef = TypedDict(
-    "ImportHypervisorConfigurationInputRequestTypeDef",
+_RequiredImportHypervisorConfigurationInputRequestTypeDef = TypedDict(
+    "_RequiredImportHypervisorConfigurationInputRequestTypeDef",
     {
         "Host": str,
         "Name": str,
-        "KmsKeyArn": NotRequired[str],
-        "Password": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
-        "Username": NotRequired[str],
     },
 )
+_OptionalImportHypervisorConfigurationInputRequestTypeDef = TypedDict(
+    "_OptionalImportHypervisorConfigurationInputRequestTypeDef",
+    {
+        "KmsKeyArn": str,
+        "Password": str,
+        "Tags": Sequence["TagTypeDef"],
+        "Username": str,
+    },
+    total=False,
+)
+
+
+class ImportHypervisorConfigurationInputRequestTypeDef(
+    _RequiredImportHypervisorConfigurationInputRequestTypeDef,
+    _OptionalImportHypervisorConfigurationInputRequestTypeDef,
+):
+    pass
+
 
 ImportHypervisorConfigurationOutputTypeDef = TypedDict(
     "ImportHypervisorConfigurationOutputTypeDef",
@@ -196,16 +225,18 @@ ImportHypervisorConfigurationOutputTypeDef = TypedDict(
 ListGatewaysInputListGatewaysPaginateTypeDef = TypedDict(
     "ListGatewaysInputListGatewaysPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListGatewaysInputRequestTypeDef = TypedDict(
     "ListGatewaysInputRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListGatewaysOutputTypeDef = TypedDict(
@@ -220,16 +251,18 @@ ListGatewaysOutputTypeDef = TypedDict(
 ListHypervisorsInputListHypervisorsPaginateTypeDef = TypedDict(
     "ListHypervisorsInputListHypervisorsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListHypervisorsInputRequestTypeDef = TypedDict(
     "ListHypervisorsInputRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListHypervisorsOutputTypeDef = TypedDict(
@@ -260,16 +293,18 @@ ListTagsForResourceOutputTypeDef = TypedDict(
 ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef = TypedDict(
     "ListVirtualMachinesInputListVirtualMachinesPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListVirtualMachinesInputRequestTypeDef = TypedDict(
     "ListVirtualMachinesInputRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListVirtualMachinesOutputTypeDef = TypedDict(
@@ -284,22 +319,37 @@ ListVirtualMachinesOutputTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
-PutMaintenanceStartTimeInputRequestTypeDef = TypedDict(
-    "PutMaintenanceStartTimeInputRequestTypeDef",
+_RequiredPutMaintenanceStartTimeInputRequestTypeDef = TypedDict(
+    "_RequiredPutMaintenanceStartTimeInputRequestTypeDef",
     {
         "GatewayArn": str,
         "HourOfDay": int,
         "MinuteOfHour": int,
-        "DayOfMonth": NotRequired[int],
-        "DayOfWeek": NotRequired[int],
     },
 )
+_OptionalPutMaintenanceStartTimeInputRequestTypeDef = TypedDict(
+    "_OptionalPutMaintenanceStartTimeInputRequestTypeDef",
+    {
+        "DayOfMonth": int,
+        "DayOfWeek": int,
+    },
+    total=False,
+)
+
+
+class PutMaintenanceStartTimeInputRequestTypeDef(
+    _RequiredPutMaintenanceStartTimeInputRequestTypeDef,
+    _OptionalPutMaintenanceStartTimeInputRequestTypeDef,
+):
+    pass
+
 
 PutMaintenanceStartTimeOutputTypeDef = TypedDict(
     "PutMaintenanceStartTimeOutputTypeDef",
@@ -344,15 +394,29 @@ TagTypeDef = TypedDict(
     },
 )
 
-TestHypervisorConfigurationInputRequestTypeDef = TypedDict(
-    "TestHypervisorConfigurationInputRequestTypeDef",
+_RequiredTestHypervisorConfigurationInputRequestTypeDef = TypedDict(
+    "_RequiredTestHypervisorConfigurationInputRequestTypeDef",
     {
         "GatewayArn": str,
         "Host": str,
-        "Password": NotRequired[str],
-        "Username": NotRequired[str],
     },
 )
+_OptionalTestHypervisorConfigurationInputRequestTypeDef = TypedDict(
+    "_OptionalTestHypervisorConfigurationInputRequestTypeDef",
+    {
+        "Password": str,
+        "Username": str,
+    },
+    total=False,
+)
+
+
+class TestHypervisorConfigurationInputRequestTypeDef(
+    _RequiredTestHypervisorConfigurationInputRequestTypeDef,
+    _OptionalTestHypervisorConfigurationInputRequestTypeDef,
+):
+    pass
+
 
 UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
@@ -370,13 +434,27 @@ UntagResourceOutputTypeDef = TypedDict(
     },
 )
 
-UpdateGatewayInformationInputRequestTypeDef = TypedDict(
-    "UpdateGatewayInformationInputRequestTypeDef",
+_RequiredUpdateGatewayInformationInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateGatewayInformationInputRequestTypeDef",
     {
         "GatewayArn": str,
-        "GatewayDisplayName": NotRequired[str],
     },
 )
+_OptionalUpdateGatewayInformationInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateGatewayInformationInputRequestTypeDef",
+    {
+        "GatewayDisplayName": str,
+    },
+    total=False,
+)
+
+
+class UpdateGatewayInformationInputRequestTypeDef(
+    _RequiredUpdateGatewayInformationInputRequestTypeDef,
+    _OptionalUpdateGatewayInformationInputRequestTypeDef,
+):
+    pass
+
 
 UpdateGatewayInformationOutputTypeDef = TypedDict(
     "UpdateGatewayInformationOutputTypeDef",
@@ -386,15 +464,28 @@ UpdateGatewayInformationOutputTypeDef = TypedDict(
     },
 )
 
-UpdateHypervisorInputRequestTypeDef = TypedDict(
-    "UpdateHypervisorInputRequestTypeDef",
+_RequiredUpdateHypervisorInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateHypervisorInputRequestTypeDef",
     {
         "HypervisorArn": str,
-        "Host": NotRequired[str],
-        "Password": NotRequired[str],
-        "Username": NotRequired[str],
     },
 )
+_OptionalUpdateHypervisorInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateHypervisorInputRequestTypeDef",
+    {
+        "Host": str,
+        "Password": str,
+        "Username": str,
+    },
+    total=False,
+)
+
+
+class UpdateHypervisorInputRequestTypeDef(
+    _RequiredUpdateHypervisorInputRequestTypeDef, _OptionalUpdateHypervisorInputRequestTypeDef
+):
+    pass
+
 
 UpdateHypervisorOutputTypeDef = TypedDict(
     "UpdateHypervisorOutputTypeDef",
@@ -407,11 +498,12 @@ UpdateHypervisorOutputTypeDef = TypedDict(
 VirtualMachineTypeDef = TypedDict(
     "VirtualMachineTypeDef",
     {
-        "HostName": NotRequired[str],
-        "HypervisorId": NotRequired[str],
-        "LastBackupDate": NotRequired[datetime],
-        "Name": NotRequired[str],
-        "Path": NotRequired[str],
-        "ResourceArn": NotRequired[str],
+        "HostName": str,
+        "HypervisorId": str,
+        "LastBackupDate": datetime,
+        "Name": str,
+        "Path": str,
+        "ResourceArn": str,
     },
+    total=False,
 )
